@@ -1,6 +1,6 @@
 import click
 
-from ftrack_ams.functions import shotnumber_to_letter, select_artist
+from ftrack_ams.functions import select_artist, shotnumber_to_letter
 
 
 def add_images_to_existing_project(session, projnumber):
